module.exports = defineTest({
	description: 'removes unneeded arguments across namespace member calls'
});
